@@ -9,7 +9,6 @@ SIMLock::SIMLock()
 SIMLock::~SIMLock()
 {
     simlock.Dispose();
-    delete &simlock;
 }
 
 void SIMLock::Run()
@@ -26,7 +25,6 @@ void SIMLock::Run()
 	    simlock.AddValidIMSI(imsi);
 	    Notifications::ShowBanner("<b>SIMLock</b> has added this SIM card to the list of allowed SIMs");
 	}
-	delete &imsi;
     }
 
     if(!simlock.IsValidIMSI(imsi))
@@ -46,7 +44,6 @@ void SIMLock::Run()
 	    simlock.AddValidIMSI(imsi);
 	    Notifications::ShowBanner("<b>SIMLock</b> has added this SIM card to the list of allowed SIMs");
 	}
-	delete &imsi;
 	simlock.MakeOnline();
     }
     else
